==> kubernetes-model-0.1.4-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class EndpointsFluent<T extends EndpointsFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Endpoints.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     List<VisitableBuilder<EndpointSubset, ?>> subsets = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public Endpoints.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Endpoints.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public T addToSubsets( EndpointSubset item){
    if (item != null) {EndpointSubsetBuilder builder = new EndpointSubsetBuilder(item);_visitables.add(builder);this.subsets.add(builder);} return (T)this;
    }
    public List<EndpointSubset> getSubsets(){
    return build(subsets);
    }
    public T withSubsets( List<EndpointSubset> subsets){
    this.subsets.clear();if (subsets != null) {for (EndpointSubset item : subsets){this.addToSubsets(item);}} return (T) this;
    }
    public SubsetsNested<T> addNewSubset(){
    return new SubsetsNested<T>();
    }
    public SubsetsNested<T> addNewSubsetLike( EndpointSubset item){
    return new SubsetsNested<T>(item);
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N endMetadata(){
            return and();
        }
            public N and(){
            return (N) EndpointsFluent.this.withMetadata(builder.build());
        }
    
}
    public class SubsetsNested<N> extends EndpointSubsetFluent<SubsetsNested<N>> implements Nested<N>{

        private final EndpointSubsetBuilder builder;
    
             SubsetsNested (){
        this.builder = new EndpointSubsetBuilder(this);
        }
             SubsetsNested ( EndpointSubset item){
        this.builder = new EndpointSubsetBuilder(this, item);
        }
    
            public N endSubset(){
            return and();
        }
            public N and(){
            return (N) EndpointsFluent.this.addToSubsets(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.9-sources.jar: annotations/io/fabric8/kubernetes/api/model/EndpointsFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class EndpointsFluent<T extends EndpointsFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     Endpoints.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     List<VisitableBuilder<EndpointSubset, ?>> subsets = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public Endpoints.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( Endpoints.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public T addToSubsets( EndpointSubset ...items){
    for (EndpointSubset item : items) {EndpointSubsetBuilder builder = new EndpointSubsetBuilder(item);_visitables.add(builder);this.subsets.add(builder);} return (T)this;
    }
    public T removeFromSubsets( EndpointSubset ...items){
    for (EndpointSubset item : items) {EndpointSubsetBuilder builder = new EndpointSubsetBuilder(item);_visitables.remove(builder);this.subsets.remove(builder);} return (T)this;
    }
    public List<EndpointSubset> getSubsets(){
    return build(subsets);
    }
    public T withSubsets( List<EndpointSubset> subsets){
    this.subsets.clear();if (subsets != null) {for (EndpointSubset item : subsets){this.addToSubsets(item);}} return (T) this;
    }
    public T withSubsets( EndpointSubset ...subsets){
    this.subsets.clear(); if (subsets != null) {for (EndpointSubset item :subsets){ this.addToSubsets(item);}} return (T) this;
    }
    public SubsetsNested<T> addNewSubset(){
    return new SubsetsNested<T>();
    }
    public SubsetsNested<T> addNewSubsetLike( EndpointSubset item){
    return new SubsetsNested<T>(item);
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
EndpointsFluent that = (EndpointsFluent) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (subsets != null ? !subsets.equals(that.subsets) :that.subsets != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N endMetadata(){
            return and();
        }
            public N and(){
            return (N) EndpointsFluent.this.withMetadata(builder.build());
        }
    
}
    public class SubsetsNested<N> extends EndpointSubsetFluent<SubsetsNested<N>> implements Nested<N>{

        private final EndpointSubsetBuilder builder;
    
             SubsetsNested ( EndpointSubset item){
        this.builder = new EndpointSubsetBuilder(this, item);
        }
             SubsetsNested (){
        this.builder = new EndpointSubsetBuilder(this);
        }
    
            public N endSubset(){
            return and();
        }
            public N and(){
            return (N) EndpointsFluent.this.addToSubsets(builder.build());
        }
    
}


}
